Expected behaviour
------------------

.. What *should* happen?

Current behaviour
-----------------

.. What *is* happening?

Steps to reproduce
------------------

Note:  This section is *required*.

1.
2.
3.

Environment Information
-----------------------

* OS:
* `jnrbase` version:
* `python` version:

Preferably, include the following too:

* `ciso8601` version:
* `cduration` version:
* `click` version:
* `configobj` version:
* `html2text` version:
* `httplib2` version:
* `Jinja2` version:
* `pygments` version:
